﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Input;
using Infragistics.Windows.Controls;

namespace pageup_down
{
    /// <summary>
    /// Subtype of <see cref="XamTabControl"/> which:
    /// <list type="bullet">
    /// <item><description>
    /// Uses ctrl-PageUp/Down to switch tabs instead of ctrl-Tab.  Ctrl-Tab is left unhandled so the normal WPF 
    /// keyboard-focus-changing logic can run.
    /// </description></item>
    /// </list>
    /// </summary>
    public class XamTabControlEx : XamTabControl
    {
        public XamTabControlEx()
        {
            // since implicit styles are based on the class type the following is 
            // needed if you want to pick up implicit styles associated with the 
            // base class (e.g. if you set the Theme property)
            this.SetResourceReference(StyleProperty, typeof(XamTabControl));
        }

        protected override void OnKeyDown(KeyEventArgs e)
        {
            if ((e.KeyboardDevice.Modifiers & ModifierKeys.Control) == ModifierKeys.Control)
            {
                if (e.Key == Key.Tab)
                {
                    // Don't set e.Handled = True and don't even call base.OnKeyDown() (which will do the same).  This 
                    // should let the event bubble up to WPF's default handling (which should be control-tab keyboard 
                    // navigation).
                }
                else if (e.Key == Key.PageDown)
                {
                    selectNextTab( 1 );
                    e.Handled = true;
                }
                else if (e.Key == Key.PageUp)
                {
                    selectNextTab( -1 );
                    e.Handled = true;
                }
                else
                    base.OnKeyDown( e );
            }
            else
                base.OnKeyDown( e );
        }

        /// <summary>
        /// Select the next tab in the given "direction" (1: forward; -1: backward), cycling around at the end.
        /// </summary>
        /// <param name="aDirection"></param>
        private void selectNextTab( int aDirection )
        {
            var sIndex = SelectedIndex;
            sIndex += aDirection;
            if (sIndex < 0)
                sIndex = Items.Count - 1;
            else if (sIndex >= Items.Count)
                sIndex = 0;
            SelectedIndex = sIndex;
        }
    }
}
